@@ -189,6 +189,8 @@ class netcdf(bb_base, hpccm.templates.ConfigureMake, hpccm.templates.envvars,
                 self.__ospackages = ['ca-certificates', 'file',
                                      'libcurl-devel', 'm4', 'make',
                                      'wget', 'zlib-devel']
+                if self.__check:
+                    self.__ospackages.append('diffutils')
             self.__runtime_ospackages = ['zlib']
         else: # pragma: no cover
             raise RuntimeError('Unknown Linux distribution')
